/// <reference types="gapi.auth2" />
/// <reference types="gapi" />
export declare type AuthorizeValue = {
    /**
     * Any error from running `gapi.auth2.authorize`
     */
    error: Error | null;
    /**
     * The response returned to the callback of the `gapi.auth2.authorize` method.
     */
    authorizeResponse: gapi.auth2.AuthorizeResponse | null;
};
/**
 * Declarative wrapper around `gapi.auth2.authorize`, read more here {@link https://developers.google.com/identity/sign-in/web/reference#gapiauth2authorizeparams_callback}
 *
 * Performs a one time OAuth 2.0 authorization.
 * Depending on the parameters used, this will open a popup to the Google
 * sign-in flow or try to load the requested response silently, without user interaction.
 */
export declare const useAuthorize: (authorizeConfig: gapi.auth2.AuthorizeConfig) => AuthorizeValue;
