/// <reference types="gapi.auth2" />
export declare type GoogleAuthValue = {
    /**
     * Returns whether the current user is currently signed in.
     */
    isSignedIn: boolean;
    /**
     * `GoogleAuth` is a singleton class that provides methods to allow the user
     * to sign in with a Google account, get the user's current sign-in status,
     * get specific data from the user's Google profile, request additional scopes,
     * and sign out from the current account.
     */
    googleAuth: gapi.auth2.GoogleAuth | null;
    /**
     * Any error from loading the `GoogleAuth` object
     */
    error: Error | null;
};
/**
 * A declarative wrapper around the `GoogleAuth` object described here {@link https://developers.google.com/identity/sign-in/web/reference#authentication}.
 *
 * This hook manages loading the `GoogleAuth` object (by calling `gapi.auth2.init`).
 * This hook also listens for changes to the signedIn state and updates the return value.
 */
export declare const useGoogleAuth: () => GoogleAuthValue;
